@@ -1456,16 +1456,14 @@ glade_property_class_update_from_node (GladeXmlNode        *node,
 	if (!buf)
 		return FALSE;
 	g_free (buf);
-
 	
-	/* If Disabled="TRUE" we set *property_class to NULL, but we return TRUE.
-	 * The caller may want to remove this property from its list.
-	 */
 	if (glade_xml_get_property_boolean (node, GLADE_TAG_DISABLED, FALSE))
 	{
-		glade_property_class_free (klass);
-		*property_class = NULL;
-		return TRUE;
+		/* Its easier for us to keep disabled properties around and
+		 * only virtually disable them */
+		klass->ignore  = TRUE;
+		klass->save    = FALSE;
+		klass->visible = FALSE;
 	}
 
 	if ((spec_node = glade_xml_search_child (node, GLADE_TAG_SPECIFICATIONS)) != NULL)
@@ -1489,12 +1487,18 @@ glade_property_class_update_from_node (GladeXmlNode        *node,
 		/* We overrode the pspec, now it *is* a virtual property. */
 		klass->virt              = TRUE;
 		
-		if (klass->tooltip) g_free (klass->tooltip);
-		if (klass->name)    g_free (klass->name);
-		
-		klass->tooltip = g_strdup (g_param_spec_get_blurb (klass->pspec));
-		klass->name    = g_strdup (g_param_spec_get_nick (klass->pspec));
-		
+		if (strcmp (g_param_spec_get_blurb (klass->pspec), "dummy") != 0)
+		{
+			g_free (klass->tooltip);
+			klass->tooltip = g_strdup (g_param_spec_get_blurb (klass->pspec));
+		}
+
+		if (strcmp (g_param_spec_get_nick (klass->pspec), "dummy") != 0)
+		{
+			g_free (klass->name);
+			klass->name = g_strdup (g_param_spec_get_nick (klass->pspec));
+		}
+
 		if (klass->pspec->flags & G_PARAM_CONSTRUCT_ONLY)
 			klass->construct_only = TRUE;
 		
@@ -1515,8 +1519,7 @@ glade_property_class_update_from_node (GladeXmlNode        *node,
 	{
 		/* If catalog file didn't specify a pspec function
 		 * and this property isn't found by introspection
-		 * we simply handle it as a property that has been
-		 * disabled.
+		 * we simply delete it from the list always.
 		 */
 		glade_property_class_free (klass);
 		*property_class = NULL;
